=========
pip2conda
=========

``pip2conda`` is a tool to translate ``pip``-style requirements into ``conda``
requirements.

``pip2conda`` reads or generates the metadata for a project - handling build and runtime
requirements including extras, dependency groups, and environment markers - before translating
each requirement into a conda-forge requirement suitable for installation with
``conda`` / ``mamba``.

.. image:: https://badge.fury.io/py/pip2conda.svg
   :target: http://badge.fury.io/py/pip2conda
   :alt: PyPI version

.. image:: https://img.shields.io/conda/vn/conda-forge/pip2conda.svg
   :target: https://anaconda.org/conda-forge/pip2conda/
   :alt: Conda version

.. image:: https://img.shields.io/pypi/l/pip2conda.svg
   :target: https://choosealicense.com/licenses/gpl-3.0/
   :alt: License

.. image:: https://img.shields.io/pypi/pyversions/pip2conda.svg
   :alt: Supported Python versions

.. raw:: html

Getting Started
===============

.. toctree::
   :maxdepth: 1

   installation
   usage

Project Information
===================

.. toctree::
   :maxdepth: 1

   changelog

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
